# -*- coding: utf-8
from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _

class InputFlowConfig(AppConfig):
    name = 'inputflow'
    varbose_name = _("Input flow")
